From 8750810f5cfceeffd5acf2f21e779d470d0dc88b Mon Sep 17 00:00:00 2001
From: Chris Robinson <chris.kcat@gmail.com>
Date: Sat, 28 Nov 2020 03:38:20 -0800
Subject: Change a couple macros into constexpr variables

---
 alc/effects/reverb.cpp | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

(limited to 'alc/effects/reverb.cpp')

diff --git a/alc/effects/reverb.cpp b/alc/effects/reverb.cpp
index 78773abf..6471b210 100644
--- a/alc/effects/reverb.cpp
+++ b/alc/effects/reverb.cpp
@@ -562,12 +562,12 @@ void ReverbState::allocLines(const float frequency)
     /* The main delay length includes the maximum early reflection delay, the
      * largest early tap width, the maximum late reverb delay, and the
      * largest late tap width.  Finally, it must also be extended by the
      * update size (BUFFERSIZE) for block processing.
      */
     float length{AL_EAXREVERB_MAX_REFLECTIONS_DELAY + EARLY_TAP_LENGTHS.back()*multiplier +
         AL_EAXREVERB_MAX_LATE_REVERB_DELAY +
         (LATE_LINE_LENGTHS.back() - LATE_LINE_LENGTHS.front())/float{NUM_LINES}*multiplier};
-    totalSamples += mDelay.calcLineLength(length, totalSamples, frequency, BUFFERSIZE);
+    totalSamples += mDelay.calcLineLength(length, totalSamples, frequency, BufferLineSize);
 
     /* The early vector all-pass line. */
     length = EARLY_ALLPASS_LENGTHS.back() * multiplier;
@@ -562,12 +562,12 @@ void ReverbState::allocLines(const float frequency)
      * largest early tap width, the maximum late reverb delay, and the
      * largest late tap width.  Finally, it must also be extended by the
-     * update size (BUFFERSIZE) for block processing.
+     * update size (BufferLineSize) for block processing.
      */
     float length{AL_EAXREVERB_MAX_REFLECTIONS_DELAY + EARLY_TAP_LENGTHS.back()*multiplier +
-- 
cgit v1.2.3